=========
ChangeLog
=========


v0.1.4
======

* Added support for TravisCI (by @jayvdb)
* Added support for Python 2.6 (by @jayvdb)


v0.1.3
======

* Removed `distribute` dependency (thanks jlec)


v0.1.2
======

* First tagged release
